from pscr_common.log import setup_logging, clear_logging_handlers
from org_mapper.mapper_v2 import str_to_bool
from org_mapper.effective_endpoints import EffectiveEndpoints
from org_mapper.shard_management import ShardManager
import logging
import os


def main():
    clear_logging_handlers()
    if str_to_bool(os.environ.get("PSCR_LOGGING", "true")):
        setup_logging(
            level=os.environ.get("LOG_LEVEL", "INFO"),
            svc_version=os.environ.get("CONTAINERVERSION", "UNKNOWN"),
            env_id=os.environ.get("ENV_ID", "UNKNOWN"),
            svc_id="TODO",
        )
    else:
        logging.basicConfig(level=os.environ.get("LOG_LEVEL", "DEBUG"))
    source_admin_bucket = os.environ.get(
        "SOURCE_ADMIN_S3_BUCKET", "dev-pscr-admin-bucket"
    )
    source_endpoint_scaler_config_key = os.environ.get(
        "SOURCE_CONFIG_S3_KEY", "org_mapper/config.json"
    )
    doc_builder_override_key = os.environ.get(
        "DOCBUILDER_OVERRIDE_S3_KEY", "docbuilder/overrides.json"
    )
    dest_kinesis_stream_name = os.environ.get("DEST_KINESIS_STREAM_NAME", "default")
    effective_endpoints_per_partition = int(
        os.environ.get("effective_endpoints_per_partition", 1024)
    )
    min_shard_util = float(os.environ.get("MIN_SHARD_UTIL", 0.5))
    max_shard_util = float(os.environ.get("MAX_SHARD_UTIL", 1.5))
    shard_settle_timer = int(os.environ.get("SHARD_SETTLE_TIMER", 0))
    disable_shard_merge = str_to_bool(os.environ.get("DISABLE_SHARD_MERGE", "false"))
    large_org_longterm_min_effective_endpoints = int(
        os.environ.get("LARGE_ORG_LONGTERM_MIN_EFFECTIVE", 150)
    )
    effective_endpoint_config = EffectiveEndpoints(
        source_admin_bucket,
        doc_builder_override_key,
        source_endpoint_scaler_config_key,
        "unused",
    )
    effective_endpoint_config.load_s3_config()
    effective_endpoint_config.flush_docbuilder_overrides()
    shard_manager = ShardManager(
        effective_endpoint_config,
        dest_kinesis_stream_name,
        effective_endpoints_per_partition,
        min_shard_util=min_shard_util,
        max_shard_util=max_shard_util,
        shard_settle_timer=shard_settle_timer,
        reshard_passes=10000,
        large_org_longterm_min_effective_endpoints=large_org_longterm_min_effective_endpoints,
    )
    shard_manager.reshard(disable_shard_merge)
